@@ -176,11 +176,18 @@ class VizCommand(BuildGraphCommand):
         writer.digraph(fontname="monospace")
         writer.set_node_style(style="filled", shape="box")
 
+        executed_tasks = set(graph.tasks())
         for task in graph.tasks(all=args.all):
             writer.node(
                 task.path,
-                color="green" if task.default else "gray20",
-                fillcolor="dodgerblue1" if isinstance(task, GroupTask) else "aquamarine",
+                penwidth="3" if task.default else "1",
+                fillcolor=(
+                    "darkgoldenrod1"
+                    if task in executed_tasks
+                    else "dodgerblue"
+                    if isinstance(task, GroupTask)
+                    else "beige"
+                ),
             )
             for predecessor in graph.get_predecessors(task):
                 writer.edge(predecessor.path, task.path)
